@@ -8,6 +8,7 @@ BASE_DIR = os.path.dirname(os.path.abspath(__file__))
 DBNAME = "base.sqlite3"
 
 
+
 def drop():
     db = sqlite3.connect(os.path.join(BASE_DIR,DBNAME))
     cursor = db.cursor()
@@ -63,6 +64,28 @@ def insert(name:str,path:str):
 
     db.commit()
 
+def update_val(name,path):
+    if not os.path.exists(path):
+        print("path not found ")
+        exit()
+
+    
+    db = sqlite3.connect(os.path.join(BASE_DIR,DBNAME))
+    cursor = db.cursor()
+    QUERY = f'''
+    
+    UPDATE projects SET path = '{path}' WHERE name = '{name}'
+    
+    '''
+    try:
+        cursor.execute(QUERY)
+        print("update data done ")
+    except Exception as e:
+        print(f"error executing QUERY [Error : {e} ] ")
+
+    db.commit()
+
+
 def fetch(name):
     db = sqlite3.connect(os.path.join(BASE_DIR,DBNAME))
     cursor = db.cursor()
